/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ActionSheetItemGroup } from "./group";
/**
 * An interface for the ActionSheet items.
 */
export interface ActionSheetItem {
    /**
     * Specifies the text content of the ActionSheet item.
     */
    title?: string;
    /**
     * Defines the name for an existing icon in a Kendo UI theme.
     * The icon is rendered inside the ActionSheet item by a `span.k-icon` element.
     */
    icon?: string;
    /**
     * Defines an [`SVGIcon`](slug:api_icons_svgicon) to be rendered within the ActionSheet item.
     */
    svgIcon?: SVGIcon;
    /**
     * Defines a CSS class — or multiple classes separated by spaces —
     * which are applied to a span element inside the ActionSheet item.
     * Allows the usage of custom icons.
     */
    iconClass?: string;
    /**
     * Defines the group of the item.
     * Items can be segregated in two groups - `top` and `bottom` -
     * each specifying whether the ActionSheet item will be rendered over the separator or under it.
     */
    group?: ActionSheetItemGroup;
    /**
     * Specifies additional text rendered under the item's title.
     */
    description?: string;
    /**
     * Specifies if the ActionSheet item is initially disabled.
     */
    disabled?: boolean;
    /**
     * Specifies the size of the icon. Accepts any valid font-size value.
     */
    iconSize?: string;
    /**
     * Specifies the color of the icon. Available options are `inherit`, `default`, `primary`, `secondary`, `tertiary`, `info`, `success`, `warning`, `error`, `dark`, `light`, `inverted` or any hexadecimal value.
     */
    iconColor?: string;
    /**
     * The CSS classes that will be rendered on the item.
     * Supports the type of values that are supported by [ngClass](link:site.data.urls.angular['ngclassapi']).
     */
    cssClass?: any;
    /**
     * The CSS styles that will be rendered on the item.
     * Supports the type of values that are supported by [ngStyle](link:site.data.urls.angular['ngstyleapi']).
     */
    cssStyle?: any;
}
