/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * An interface for describing the BottomNavigation items ([see example](slug:items_bottomnavigation)).
 */
export interface BottomNavigationItem {
    /**
     * Disables the BottomNavigation item.
     */
    disabled?: boolean;
    /**
     * Defines the name of an existing icon in a Kendo UI theme.
     */
    icon?: string;
    /**
     * Defines a CSS class or multiple classes separated by spaces, which are applied to a span element inside the item. Allows the usage of custom icons.
     */
    iconClass?: string;
    /**
     * Defines an [`SVGIcon`](slug:api_icons_svgicon) to be rendered within the BottomNavigation item.
     */
    svgIcon?: SVGIcon;
    /**
     * Specifies, if the BottomNavigation item is selected.
     */
    selected?: boolean;
    /**
     * Sets the tabIndex property of the BottomNavigation item.
     *
     * @default 0
     *
     */
    tabIndex?: number;
    /**
     * Specifies the text content of the BottomNavigation item.
     */
    text?: string;
    /**
     * The CSS classes that will be rendered on the item element of the BottomNavigation. Supports the type of values that are supported by [ngClass](link:site.data.urls.angular['ngclassapi'])..
     */
    cssClass?: any;
    /**
     * The CSS styles that will be rendered on the item element of the BottomNavigation. Supports the type of values that are supported by [ngStyle](link:site.data.urls.angular['ngstyleapi']).
     */
    cssStyle?: any;
}
